import os
import glob
import matplotlib.pyplot as plt
from mpl_toolkits.axes_grid1.anchored_artists import AnchoredSizeBar
import matplotlib.font_manager as fm
import matplotlib.patheffects as patheffects
from mpl_toolkits.axes_grid1.inset_locator import inset_axes
import pixstem.api as ps

directory = "d004_dpc_cor_plot"
data_dir = "d002_dpc_cor/"
if not os.path.exists(directory):
    os.makedirs(directory)

filename_list = glob.glob(data_dir + "*_dpc_cor.hspy")
filename_list.sort()

for filename in filename_list:
    s = ps.load_dpc_signal(filename)
    s1 = s.correct_ramp(only_offset=True)
    filename = os.path.split(filename)[-1]
    filename_output = os.path.join(directory, filename.replace(".hspy", ".jpg"))

    ########################
    ar = s1.axes_manager[1].size / s1.axes_manager[2].size
    fig_x = 5
    fig, ax = plt.subplots(1, 1, figsize=(fig_x * ar, fig_x))
    ax_inset = inset_axes(ax, 0.5, 0.5, loc=1)

    s1.get_color_image_with_indicator(ax=ax, ax_indicator=ax_inset)

    a, vertical0 = ax.transData.inverted().transform(ax.transAxes.transform((0.2, 0.2)))
    a, vertical1 = ax.transData.inverted().transform(ax.transAxes.transform((0.2, 0.2)))
    fontprops = fm.FontProperties(size=22)
    scalebar = AnchoredSizeBar(
	    ax.transData,
	    2, '2 um', 4,
	    pad=0.1,
	    frameon=False,
	    color='white',
	    size_vertical=vertical0-vertical1,
	    label_top=True,
	    fontproperties=fontprops)
    ax.add_artist(scalebar)

    fig.subplots_adjust(0, 0, 1, 1)
    fig.savefig(filename_output, dpi=200)
